pub trait ParallelExtSortExtension<'a>: Iteratorwhere
    Self::Item: Send,
{ fn par_external_sort_by<F>(
        self,
        options: ExtsortConfig,
        comparator: F
    ) -> Result<ParallelResultIterator<'a, Self::Item, FuncOrderer<F>>>
    where
        F: Fn(&Self::Item, &Self::Item) -> Ordering + Send + Sync
; fn par_external_sort_by_key<F, K>(
        self,
        options: ExtsortConfig,
        key_extractor: F
    ) -> Result<ParallelResultIterator<'a, Self::Item, KeyOrderer<F>>>
    where
        F: Fn(&Self::Item) -> K + Send + Sync,
        K: Ord
; }

Required Methods

Sorts the provided Iterator according to the provided config using a custom comparison function.

Errors

This function may error if a sort file fails to be written. In this case the library will do its best to clean up the already written files, but no guarantee is made.

Sorts the provided Iterator according to the provided config using a key extraction function.

Errors

This function may error if a sort file fails to be written. In this case the library will do its best to clean up the already written files, but no guarantee is made.

Implementors