pub trait ParallelExtSortOrdExtension: Iteratorwhere
    Self::Item: Send,{
    // Required method
    fn par_external_sort(
        self,
        options: ExtsortConfig
    ) -> Result<ParallelResultIterator<Self::Item, OrdOrderer>>;
}

Required Methods

source

fn par_external_sort( self, options: ExtsortConfig ) -> Result<ParallelResultIterator<Self::Item, OrdOrderer>>

Sorts the provided Iterator according to the provided config the native ordering specified on the iterated type.

Errors

This function may error if a sort file fails to be written. In this case the library will do its best to clean up the already written files, but no guarantee is made.

Implementors

source

impl<I, T> ParallelExtSortOrdExtension for Iwhere I: Iterator<Item = T>, T: Send + Ord,