pub trait ParallelExtSortOrdExtension<'a>: Iteratorwhere
Self::Item: Send,{
fn par_external_sort(
self,
options: ExtsortConfig
) -> Result<ParallelResultIterator<'a, Self::Item, OrdOrderer>>;
}Required Methods
sourcefn par_external_sort(
self,
options: ExtsortConfig
) -> Result<ParallelResultIterator<'a, Self::Item, OrdOrderer>>
fn par_external_sort(
self,
options: ExtsortConfig
) -> Result<ParallelResultIterator<'a, Self::Item, OrdOrderer>>
Sorts the provided Iterator according to the provided config the native ordering specified on the iterated type.
Errors
This function may error if a sort file fails to be written. In this case the library will do its best to clean up the already written files, but no guarantee is made.