pub trait ExtSortByExtension<'a>: Iterator {
    fn external_sort_by<F>(
        self,
        options: ExtsortConfig,
        comparator: F
    ) -> Result<ResultIterator<'a, Self::Item, FuncOrderer<F>>>
    where
        F: Fn(&Self::Item, &Self::Item) -> Ordering
; fn external_sort_by_key<F, K>(
        self,
        options: ExtsortConfig,
        key_extractor: F
    ) -> Result<ResultIterator<'a, Self::Item, KeyOrderer<F>>>
    where
        F: Fn(&Self::Item) -> K,
        K: Ord
; }

Required Methods

Sorts the provided Iterator according to the provided config using a custom comparator function

Errors

This function may error if a sort file fails to be written. In this case the library will do its best to clean up the already written files, but no guarantee is made.

Sorts the provided Iterator according to the provided config using a key extraction function.

Errors

This function may error if a sort file fails to be written. In this case the library will do its best to clean up the already written files, but no guarantee is made.

Implementors