pub trait ExtSortOrdExtension: Iterator {
// Required method
fn external_sort(
self,
options: ExtsortConfig,
) -> Result<LoserTree<Self::Item, ExternalRun<Self::Item, Box<dyn Read + Send>>, OrdOrderer>>;
}Required Methods
Sourcefn external_sort(
self,
options: ExtsortConfig,
) -> Result<LoserTree<Self::Item, ExternalRun<Self::Item, Box<dyn Read + Send>>, OrdOrderer>>
fn external_sort( self, options: ExtsortConfig, ) -> Result<LoserTree<Self::Item, ExternalRun<Self::Item, Box<dyn Read + Send>>, OrdOrderer>>
Sorts the provided Iterator according to the provided config using the native ordering on the type to sort
Errors
This function may error if a sort file fails to be written. In this case the library will do its best to clean up the already written files, but no guarantee is made.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".