pub trait ExtSortOrdExtension<'a>: Iterator {
fn external_sort(
self,
options: ExtsortConfig
) -> Result<ResultIterator<'a, Self::Item, OrdOrderer>>;
}Required Methods
sourcefn external_sort(
self,
options: ExtsortConfig
) -> Result<ResultIterator<'a, Self::Item, OrdOrderer>>
fn external_sort(
self,
options: ExtsortConfig
) -> Result<ResultIterator<'a, Self::Item, OrdOrderer>>
Sorts the provided Iterator according to the provided config using the native ordering on the type to sort
Errors
This function may error if a sort file fails to be written. In this case the library will do its best to clean up the already written files, but no guarantee is made.