Struct extsort_iter::ExtsortConfig
source · [−]pub struct ExtsortConfig {
pub temp_file_folder: PathBuf,
/* private fields */
}Expand description
The configuration for the external sorting.
Fields
temp_file_folder: PathBufImplementations
sourceimpl ExtsortConfig
impl ExtsortConfig
sourcepub fn create_with_buffer_size_for<T>(sort_buf_bytes: usize) -> Self
pub fn create_with_buffer_size_for<T>(sort_buf_bytes: usize) -> Self
Creates a configuration with a specified sort buffer size in bytes and a sort directory of /tmp
sourcepub fn default_for<T>() -> Self
pub fn default_for<T>() -> Self
Creates a configuration with a sort buffer size of 10M and a sort directory of /tmp
sourcepub fn temp_file_folder(self, folder: impl Into<PathBuf>) -> Self
pub fn temp_file_folder(self, folder: impl Into<PathBuf>) -> Self
Updates the temp_file_folder attribute. Useful for fluent-style api usage.